@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' project.
- * Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
+ * Copyright (c) 2013-2023, Marek Gagolewski <https://www.gagolewski.com/>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -149,8 +149,9 @@ DateFormat* stri__get_date_format(
  * @version 0.5-1 (Marek Gagolewski, 2015-02-22) use tz
  * @version 1.6.3 (Marek Gagolewski, 2021-05-24) #434: vectorise wrt format
  */
-SEXP stri_datetime_format(SEXP time, SEXP format, SEXP tz, SEXP locale) {
-    const char* locale_val = stri__prepare_arg_locale(locale, "locale", true);
+SEXP stri_datetime_format(SEXP time, SEXP format, SEXP tz, SEXP locale)
+{
+    const char* locale_val = stri__prepare_arg_locale(locale, "locale");
     PROTECT(time = stri__prepare_arg_POSIXct(time, "time"));
     PROTECT(format = stri__prepare_arg_string(format, "format"));
 
@@ -168,13 +169,12 @@ SEXP stri_datetime_format(SEXP time, SEXP format, SEXP tz, SEXP locale) {
     StriContainerDouble time_cont(time, vectorize_length);
     StriContainerUTF8 format_cont(format, vectorize_length);
 
-    UErrorCode status = U_ZERO_ERROR;
-    cal = Calendar::createInstance(locale_val, status);
-    STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
+    cal = stri__get_calendar(locale_val);
 
     cal->adoptTimeZone(tz_val);
     tz_val = NULL; /* The Calendar takes ownership of the TimeZone. */
 
+    UErrorCode status = U_ZERO_ERROR;
     SEXP ret;
     STRI__PROTECT(ret = Rf_allocVector(STRSXP, vectorize_length));
 
@@ -264,9 +264,11 @@ SEXP stri_datetime_format(SEXP time, SEXP format, SEXP tz, SEXP locale) {
  * @version 0.5-1 (Marek Gagolewski, 2015-03-01) set tzone attrib on retval
  * @version 1.6.3 (Marek Gagolewski, 2021-05-24) #434: vectorise wrt format
  * @version 1.6.3 (Marek Gagolewski, 2021-06-07) empty retval should have a class too
+ * @version 1.8.1 (Marek Gagolewski, 2023-11-08) #469: default time is midnight today
  */
-SEXP stri_datetime_parse(SEXP str, SEXP format, SEXP lenient, SEXP tz, SEXP locale) {
-    const char* locale_val = stri__prepare_arg_locale(locale, "locale", true);
+SEXP stri_datetime_parse(SEXP str, SEXP format, SEXP lenient, SEXP tz, SEXP locale)
+{
+    const char* locale_val = stri__prepare_arg_locale(locale, "locale");
     PROTECT(str = stri__prepare_arg_string(str, "str"));
     PROTECT(format = stri__prepare_arg_string(format, "format"));
     bool lenient_val = stri__prepare_arg_logical_1_notNA(lenient, "lenient");
@@ -275,13 +277,12 @@ SEXP stri_datetime_parse(SEXP str, SEXP format, SEXP lenient, SEXP tz, SEXP loca
 
     R_len_t vectorize_length = stri__recycling_rule(true, 2, LENGTH(str), LENGTH(format));
     if (vectorize_length <= 0) {
-        UNPROTECT(3);
         SEXP ret;
         PROTECT(ret = Rf_allocVector(REALSXP, 0));
         if (!Rf_isNull(tz))
             Rf_setAttrib(ret, Rf_ScalarString(Rf_mkChar("tzone")), tz);
         stri__set_class_POSIXct(ret);
-        UNPROTECT(1);
+        UNPROTECT(4);
         return ret;
     }
 
@@ -292,15 +293,16 @@ SEXP stri_datetime_parse(SEXP str, SEXP format, SEXP lenient, SEXP tz, SEXP loca
     StriContainerUTF16 str_cont(str, vectorize_length);
     StriContainerUTF8 format_cont(format, vectorize_length);
 
-    UErrorCode status = U_ZERO_ERROR;
-    cal = Calendar::createInstance(locale_val, status);
-    STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
+    cal = stri__get_calendar(locale_val);
 
     cal->adoptTimeZone(tz_val);
     tz_val = NULL; /* The Calendar takes ownership of the TimeZone. */
 
     cal->setLenient(lenient_val);
 
+    UDate now = cal->getNow();
+
+    UErrorCode status = U_ZERO_ERROR;
     SEXP ret;
     STRI__PROTECT(ret = Rf_allocVector(REALSXP, vectorize_length));
 
@@ -330,6 +332,18 @@ SEXP stri_datetime_parse(SEXP str, SEXP format, SEXP lenient, SEXP tz, SEXP loca
         }
 
         status = U_ZERO_ERROR;
+        cal->setTime(now, status);
+        STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
+
+        // weirdly, all the time fields must be reset
+        cal->clear(UCAL_MILLISECOND);
+        cal->clear(UCAL_SECOND);
+        cal->clear(UCAL_MINUTE);
+        cal->clear(UCAL_AM_PM);
+        cal->clear(UCAL_HOUR);
+        cal->clear(UCAL_HOUR_OF_DAY);
+        cal->clear(UCAL_MILLISECONDS_IN_DAY);
+
         ParsePosition pos;
         fmt->parse(str_cont.get(i), *cal, pos);
 
